==> apache-paimon-1.0.0-src.tgz: paimon-1.0.0/paimon-core/src/main/java/org/apache/paimon/compact/NoopCompactManager.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.paimon.compact;

import org.apache.paimon.CoreOptions;
import org.apache.paimon.io.DataFileMeta;
import org.apache.paimon.utils.Preconditions;

import java.io.IOException;
import java.util.Collections;
import java.util.List;
import java.util.Optional;
import java.util.concurrent.ExecutionException;

/** A {@link CompactManager} which never compacts. */
public class NoopCompactManager implements CompactManager {

    public NoopCompactManager() {}

    @Override
    public boolean shouldWaitForLatestCompaction() {
        return false;
    }

    @Override
    public boolean shouldWaitForPreparingCheckpoint() {
        return false;
    }

    @Override
    public void addNewFile(DataFileMeta file) {}

    @Override
    public List<DataFileMeta> allFiles() {
        return Collections.emptyList();
    }

    @Override
    public void triggerCompaction(boolean fullCompaction) {
        Preconditions.checkArgument(
                !fullCompaction,
                "NoopCompactManager does not support user triggered compaction.\n"
                        + "If you really need a guaranteed compaction, please set "
                        + CoreOptions.WRITE_ONLY.key()
                        + " property of this table to false.");
    }

    @Override
    public Optional<CompactResult> getCompactionResult(boolean blocking)
            throws ExecutionException, InterruptedException {
        return Optional.empty();
    }

    @Override
    public void cancelCompaction() {}

    @Override
    public boolean isCompacting() {
        return false;
    }

    @Override
    public void close() throws IOException {}
}

==> apache-paimon-1.1.1-src.tgz: paimon-1.1.1/paimon-core/src/main/java/org/apache/paimon/compact/NoopCompactManager.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.paimon.compact;

import org.apache.paimon.CoreOptions;
import org.apache.paimon.io.DataFileMeta;
import org.apache.paimon.utils.Preconditions;

import java.io.IOException;
import java.util.Collections;
import java.util.List;
import java.util.Optional;
import java.util.concurrent.ExecutionException;

/** A {@link CompactManager} which never compacts. */
public class NoopCompactManager implements CompactManager {

    public NoopCompactManager() {}

    @Override
    public boolean shouldWaitForLatestCompaction() {
        return false;
    }

    @Override
    public boolean shouldWaitForPreparingCheckpoint() {
        return false;
    }

    @Override
    public void addNewFile(DataFileMeta file) {}

    @Override
    public List<DataFileMeta> allFiles() {
        return Collections.emptyList();
    }

    @Override
    public void triggerCompaction(boolean fullCompaction) {
        Preconditions.checkArgument(
                !fullCompaction,
                "NoopCompactManager does not support user triggered compaction.\n"
                        + "If you really need a guaranteed compaction, please set "
                        + CoreOptions.WRITE_ONLY.key()
                        + " property of this table to false.");
    }

    @Override
    public Optional<CompactResult> getCompactionResult(boolean blocking)
            throws ExecutionException, InterruptedException {
        return Optional.empty();
    }

    @Override
    public void cancelCompaction() {}

    @Override
    public boolean compactNotCompleted() {
        return false;
    }

    @Override
    public void close() throws IOException {}
}
